Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FileDescriptorSet ¶
func FileDescriptorSet(dir string, args ...string) (*desc.FileDescriptorSet, error)
FileDescriptorSet will load a single Gunk package, and return the proto FileDescriptor set of the Gunk package.
Currently, we only generate a FileDescriptorSet for one Gunk package.
Types ¶
type Generator ¶
func NewGenerator ¶ added in v0.7.0
func (*Generator) GeneratePkg ¶
GeneratePkg runs the proto files resulting from translating gunk packages through a code generator, such as protoc-gen-go to generate Go packages.
Generated files are written to the same directory, next to the source gunk files.
It is fine to pass the plugin.CodeGeneratorRequest to every protoc generator unaltered; this is what protoc does when calling out to the generators and the generators should already handle the case where they have nothing to do.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.